<template>
  <div class="bar-chart">
    <ChartTitle name="车间正品率"></ChartTitle>
    <div class="bar-contents">
      <div class="bar-total">
        <div class="bar-item">当日合计生产：{{ chartData.total }}</div>
        <div class="bar-item">正品率：{{ chartData.rate }}</div>
      </div>
      <div class="chart" ref="chart"></div>
    </div>
  </div>
</template>

<script>
import ChartTitle from "@/views/cockpitPage/components/ChartTitle.vue";
//引入echart
import * as echarts from "echarts";
let myChart;
export default {
  components: {
    ChartTitle,
  },
  props: {
    chartData: {
      type: Object,
      require: true,
      default: () => {
        return {
          total: 0,
          rate: "0",
          datax: [],
          datay: [],
          datay2: [],
        };
      },
    },
  },
  data() {
    return {
      // chartData: {
      //   total: 1000,
      //   rate: "99%",
      //   datax: [
      //     "第一车间",
      //     "第二车间",
      //     "第三车间",
      //     "第四车间",
      //     "第五车间",
      //     "第六车间",
      //     "第七车间",
      //     "第八车间",
      //     "第九车间",
      //   ],
      //   datay: [120, 200, 150, 180, 170, 150, 130, 180, 140],
      //   datay2: [20, 30, 50, 40, 70, 50, 30, 80, 40],
      // },
      startValue: 0,
      endValue: 5,
      chartTimer: null,
    };
  },
  watch: {
    "chartData.datay"(val) {
      this.startValue = 0;
      this.endValue = 5;
      this.pieChart("chart", this.chartData);
    },
  },
  mounted() {
    // this.pieChart("chart", this.chartData);
  },
  methods: {
    //在职
    pieChart(chartName, data) {
      let that = this;
      clearInterval(this.chartTimer);
      let chartDom = this.$refs[chartName];
      if (myChart != null && myChart != "" && myChart != undefined) {
        myChart.dispose(); //销毁
      }
      myChart = echarts.init(chartDom);
      let option;
      let lineColor = "#35ddc74d";
      if (data) {
        option = {
          color: ["#dcb018", "#00FFFF"],
          tooltip: {
            trigger: "axis",
            axisPointer: {
              type: "none",
            },
            textStyle: {
              color: "#00FFFF",
            },
            borderColor: "#00FFFF",
            backgroundColor: "#238d8d6b",
            formatter: function (a) {
              let list = [];
              let listItem = "";
              let firstString =
                '<span style=width:70px;display:inline-block">' +
                "生产总数" +
                "</span>&nbsp;" +
                data.total;
              list.push(firstString);
              for (let i in a) {
                let str =
                  '<span style=width:70px;display:inline-block">' +
                  a[i].seriesName +
                  "</span>&nbsp;" +
                  a[i].value;

                list.push(str);
              }
              let lastString =
                '<span style=width:70px;display:inline-block">' +
                "正品率" +
                "</span>&nbsp;" +
                data.rate;
              list.push(lastString);
              listItem = list.join("<br>");
              return '<div class="showBox">' + listItem + "</div>";
            },
          },
          grid: {
            right: "10px",
            bottom: "60px",
            left: "10px",
            top: "10px",
          },
          dataZoom: [
            {
              type: "inside",
              xAxisIndex: 0,
              show: false,
              startValue: that.startValue, // 从头开始
              endValue: that.endValue, // 一次性展示几个
            },
          ],
          legend: {
            itemWidth: 8,
            itemHeight: 8,
            itemGap: 35, //间距
            bottom: "5px",
            left: "center",
            data: [
              {
                name: "正品数量",
                icon: "circle",
                textStyle: {
                  color: "#dcb018",
                },
              },
              {
                name: "次品数量",
                icon: "circle",
                textStyle: {
                  color: "#00FFFF",
                },
              },
            ],
          },
          xAxis: [
            {
              type: "category",
              axisTick: {
                show: false,
              },
              axisLine: {
                show: true,
                lineStyle: {
                  color: lineColor,
                },
              },
              axisLabel: {
                margin: 10,
                show: true,
                textStyle: {
                  color: "#00FFFF",
                },
                formatter: function (value) {
                  if (value.length > 4) {
                    return `${value.slice(0, 3)}...`;
                  }
                  return value;
                },
              },
              data: data.datax ? data.datax : [],
            },
          ],
          yAxis: [
            {
              type: "value",
              name: "",
              minInterval: 1, //坐标轴是整数
              max: Math.ceil(eval(`Math.max(${data.datay})`) / 5) * 5, //数据最大值加3
              interval:
                (Math.ceil(eval(`Math.max(${data.datay})`) / 5) * 5) / 5,
              position: "left",
              axisLine: {
                show: true,
                lineStyle: {
                  color: lineColor,
                },
              },
              nameTextStyle: {
                color: "#00FFFF",
              },
              splitLine: {
                show: true,
                lineStyle: {
                  // 使用深浅的间隔色
                  color: lineColor,
                },
              },
              axisTick: {
                show: false,
              },
              axisLabel: {
                textStyle: {
                  color: "#9B9B9B",
                },
                formatter: "",
              },
            },
            {
              type: "value",
              name: "",
              // min: data.yAxis[0].min?data.yAxis.min:0,
              minInterval: 1, //坐标轴是整数
              max: Math.ceil(eval(`Math.max(${data.datay2})`) / 5) * 5, //数据最大值加3
              interval:
                (Math.ceil(eval(`Math.max(${data.datay2})`) / 5) * 5) / 5,
              position: "right",
              axisLine: {
                show: true,
                lineStyle: {
                  color: lineColor,
                },
              },
              nameTextStyle: {
                color: "#00FFFF",
              },
              splitLine: {
                show: true,
                lineStyle: {
                  // 使用深浅的间隔色
                  color: lineColor,
                },
              },
              axisTick: {
                show: false,
              },
              axisLabel: {
                textStyle: {
                  color: "#9B9B9B",
                },
                formatter: "",
              },
            },
          ],
          series: [
            {
              type: "bar",
              name: "正品数量",
              barWidth: "15",
              itemStyle: {
                normal: {
                  //柱形图圆角，初始化效果
                  barBorderRadius: [4, 4, 0, 0],
                },
              },
              data: data.datay,
            },
            {
              type: "bar",
              name: "次品数量",
              barWidth: "15",
              itemStyle: {
                normal: {
                  //柱形图圆角，初始化效果
                  barBorderRadius: [4, 4, 0, 0],
                },
              },
              data: data.datay2,
            },
          ],
        };
        this.chartTimer = setInterval(function () {
          // 每次向左滑动一个，最后一个从头开始。
          if (option.dataZoom[0].endValue == that.chartData.datay.length) {
            option.dataZoom[0].startValue = that.startValue;
            option.dataZoom[0].endValue = that.endValue;
          } else {
            option.dataZoom[0].endValue = option.dataZoom[0].endValue + 1;
            option.dataZoom[0].startValue = option.dataZoom[0].startValue + 1;
          }
          myChart.setOption(option);
        }, 3000);

        option && myChart.setOption(option);
        window.addEventListener("resize", function () {
          myChart.resize();
        });
      } else {
        option = {};
        myChart.setOption(option, true);
      }
    },
  },
};
</script>

<style scoped lang="scss">
.bar-chart {
  width: 100%;
  height: calc(100% - 20px);
  padding: 20px 0 0;
  .bar-contents {
    width: 100%;
    height: calc(100% - 60px);
    border: 1px solid #00ffff;
    box-sizing: border-box;
    .bar-total {
      width: 100%;
      height: 30px;
      line-height: 30px;
      color: #dcb018;
      font-size: 14px;
      margin-top: 10px;
      .bar-item {
        width: 50%;
        text-align: center;
        float: left;
      }
    }
    .chart {
      width: 100%;
      height: calc(100% - 40px);
    }
  }
}
</style>
